@@ -95,8 +95,18 @@ def forecast_near(
     daily_lift_est=1000,
 ):
 
-    # no historical data
-    if type(validated_tank_history) != pd.core.frame.DataFrame:
+    # less than 9 days of historical data
+    if validated_tank_history is None:
+        validated_tank_history = pd.DataFrame(columns=['ds', 'y'])
+
+    if len(validated_tank_history) < 432:
+
+        if validated_tank_history.empty:
+            now = datetime.now()
+            now_hh = now - (now - datetime.min) % timedelta(minutes=30)
+
+        else:
+            now_hh = validated_tank_history["ds"].iloc[-1]
 
         forecast = forecast_far(
             sales_history=[],
@@ -105,8 +115,6 @@ def forecast_near(
             daily_lift_est=daily_lift_est,
             forecast_length=3,
         )
-        now = datetime.now()
-        now_hh = now - (now - datetime.min) % timedelta(minutes=30)
         fake_data = {"ds": [now_hh], "sales": [0]}
         validated_tank_history = pd.DataFrame(data=fake_data)
 
@@ -131,6 +139,13 @@ def forecast_near(
         output = predictions[["ds", "hh"]].copy()
         output.rename(columns={"hh": "yhat"}, inplace=True)
 
+        output["lower"] = output["yhat"] - 2 * output["yhat"].std()
+        output["upper"] = output["yhat"] + 2 * output["yhat"].std()
+
+        # non-negative predictions
+        for field in ["yhat", "lower", "upper"]:
+            output.loc[output[field] < 0, field] = 0
+
         return output
 
     future = gen_future(
